@@ -176,8 +176,12 @@ namespace
 		}
 
 		QTextDocument document;
+		QTextCursor cursor(&document);
+		cursor.mergeBlockFormat(textCursor().blockFormat());
 		int formats = document.allFormats().size();
-		QTextCursor cursor = m_document->isRichText() ? textCursor() : QTextCursor(&document);
+		if (m_document->isRichText()) {
+			cursor = textCursor();
+		}
 
 		QByteArray richtext;
 		if (source->hasFormat(QLatin1String("application/vnd.oasis.opendocument.text"))) {
@@ -840,6 +844,8 @@ bool Document::loadFile(const QString& filename, int position)
 	m_saved_wordcount = m_document_stats.wordCount();
 	if (enabled) {
 		m_highlighter->setEnabled(true);
+	} else {
+		m_highlighter->rehighlight();
 	}
 	connect(m_text->document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(updateWordCount(int,int,int)));
 	connect(m_text->document(), SIGNAL(undoCommandAdded()), this, SLOT(undoCommandAdded()));
@@ -896,6 +902,7 @@ void Document::loadTheme(const Theme& theme)
 		m_text->document()->setModified(false);
 		m_spacings_loaded = true;
 	}
+
 	m_text->setTabStopWidth(tab_width);
 	m_text->document()->setIndentWidth(tab_width);
 
@@ -932,6 +939,7 @@ void Document::loadTheme(const Theme& theme)
 		// Stretched
 		m_layout->setColumnStretch(0, 0);
 		m_layout->setColumnStretch(2, 0);
+		break;
 	case 1:
 	default:
 		// Centered
@@ -1166,8 +1174,8 @@ void Document::focusText()
 		break;
 
 	case 2: // Current line and previous two lines
-		selection.cursor.movePosition(QTextCursor::StartOfLine);
 		selection.cursor.movePosition(QTextCursor::Up);
+		selection.cursor.movePosition(QTextCursor::StartOfLine);
 		selection.cursor.movePosition(QTextCursor::Down, QTextCursor::KeepAnchor, 2);
 		selection.cursor.movePosition(QTextCursor::EndOfLine, QTextCursor::KeepAnchor);
 		break;
